# LSB Compliant packages require the following in ~/.rpmmacros
#%_binary_payload	w9.gzdio

Summary: LSB Distribution Testkit Manager
Vendor: ISPRAS
# name, ver, rel are passed in from Makefile so we only have to set them one place
Name: %{name}
Version: %{ver}
Release: %{rel}
Source: %{name}-%{version}.src.tgz
License: GPL
URL: http://www.linux-foundation.org/en/Downloads
Group: Development/Tools
Buildroot: %{_builddir}/%{name}-root
AutoReqProv: no

%description
LSB Distribution Testkit wraps all the current LSB test suites into a
user-friendly "single LSB test suite" with unified test management and
analysis capabilities. This facilitates test execution and results analysis
thus making the LSB tests more attractive for upstream developers as well as
making certification process technically more inviting.

%prep
if [ ! -x /opt/lsb/bin/lsbcc ] ; then
    printf "lsbcc not found, required for compilation, aborting\n"
    exit 1
fi

%setup

%build
# Build autotest binary
export LSBCC_LSBVERSION=3.1
export CC=/opt/lsb/bin/lsbcc
#export CFLAGS=-fno-stack-protector
cd autotest && make clean && make && make clean && cd -

# Build man page
[ -d man/man1 ] || mkdir -p man/man1
pod2man autotest-ext/lsb-tef.pl man/man1/lsb-tef.pl.1 -r 'The Linux Foundation' -c '' -n lsb-tef.pl
pod2man man/man1/dtk-manager.pod man/man1/dtk-manager.1 -r 'The Linux Foundation' -c '' -n dtk-manager

%install

rm -rf $RPM_BUILD_ROOT/opt/lsb/test/manager
mkdir -p $RPM_BUILD_ROOT/opt/lsb/test/manager
cp -r autotest-ext webui bin php_auto_results $RPM_BUILD_ROOT/opt/lsb/test/manager
cp -rf man $RPM_BUILD_ROOT/opt/lsb
rm $RPM_BUILD_ROOT/opt/lsb/man/man1/dtk-manager.pod
cp -r LICENSE README $RPM_BUILD_ROOT/opt/lsb/test/manager
mkdir -p $RPM_BUILD_ROOT/opt/lsb/test/manager/autotest
cd autotest
cp -r AUTHORS CHANGELOG LICENSE lsb-autotest lsb-autotest-reporter \
	README VERSION $RPM_BUILD_ROOT/opt/lsb/test/manager/autotest
cd -

%files
%defattr(-,root,root)
/opt/lsb/test/manager
%doc /opt/lsb/test/manager/README
%doc /opt/lsb/man/man1/lsb-tef.pl.1
%doc /opt/lsb/man/man1/dtk-manager.1

%post
echo "Installed successfully."
RESULT=0

if [ ! -x /usr/bin/perl ] ; then
	echo
	echo "Warning: Couldn't find  /usr/bin/perl."
	echo "Perl is required for LSB DTK Manager. Please, install it"
	echo "using the tools provided by your distro."
	echo
	RESULT=1
fi

if ! which lsb_release >/dev/null 2>&1; then
	echo
	echo "Warning: Couldn't find the required tool: lsb_release."
	echo "lsb_release should be always present for a LSB compliant distro."
	echo "You could install lsb_release and other LSB components using"
	echo "the tools provided by your distro."
	echo
	RESULT=1
fi

if lsb_release 2>&1 | grep "No LSB modules" >/dev/null 2>&1; then
	echo
	echo "Warning: No LSB modules are available."
	echo "You could install LSB modules using the tools provided by"
	echo "your distro."
	echo
	RESULT=1
fi

if ! which Xvfb >/dev/null 2>&1; then
	echo
	echo "Warning: Couldn't find the required tool: Xvfb (X Virtual Frame Buffer)."
	echo "Xvfb is required for X11 tests for LSB 3.0 and 3.1. If you are going"
	echo "to run these tests or to get certified for these LSB versions,"
	echo "you should install Xvfb using the tools provided by your distribution."
	echo
	RESULT=1
fi

# put out a message
echo "__________________________________________________________________________"
echo "ATTENTION!"
echo
echo "This tool runs as the root user and installs packages on its own!"
echo "Therefore it can do pretty much harm if it gets out of control."
echo "We have tried to make the script reasonably safe but there is no warranty."
echo "Use it at YOUR OWN RISK only, and only if you know what you are doing."
echo
echo "Some setuid and setgid binaries may be generated and left behind after"
echo "execution of the test suites (especially if certain tests fail)."
echo "You should not install this package on production systems"
echo "or in situations where local users are not completely trusted."
echo
echo "PLEASE DO NOT RUN IT ON A MACHINE THAT HOLDS IMPORTANT DATA, OR PROVIDES"
echo "IMPORTANT SERVICES!"
echo "__________________________________________________________________________"
echo
echo "LSB Distribution Testkit Manager has been installed to"
echo "/opt/lsb/test/manager."
if [ $RESULT -ne 0 ]; then
	echo
	echo "There were warnings."
fi
echo
echo "Use /opt/lsb/test/manager/bin/lsb-dtk-start.sh to run LSB DTK Manager."
echo
echo "Read more info at"
echo "http://ispras.linux-foundation.org/index.php/About_LSB_Distribution_Testkit_Manager"
echo

# End of the postinstall script.

%postun
if [ $1 = "0" -o $1 = "remove" ]; then
	echo " LSB Distribution Testkit Manager has been uninstalled."
	if [ -d /var/opt/lsb/test/manager ]; then
		echo " There are files left in /var/opt/lsb/test/manager. You could delete them all."
	fi
fi

%clean
if [ -e "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then
    rm -rf ${RPM_BUILD_ROOT}
fi
